<?php
/**
 * The default template for displaying content
 *
 * Used for both single and index/archive/search.
 *
 * @package WordPress
 * @subpackage Simpods MVC
 * @since 1.0
 * @version 1.0
 */
?>

<article id="post-<?php the_ID(); ?>"<?php post_class(); ?>>
	<?php

	if ( is_sticky() && is_home() && !is_paged() ) { ?>
	<div class="featured-post">
		<?php esc_html_e( 'Featured Post', 'simpods-mvc' ); ?>
	</div>
	<?php }

	?>

	<!-- Header -->
	<header class="entry-header">
		<?php

		if ( !post_password_required() && !is_attachment() ) {
			the_post_thumbnail();
		}

		if ( is_single() ) {
			?>
		<h1 class="entry-title"><?php the_title(); ?></h1>
		<?php } else {?>
		<h1 class="entry-title">
			<a href="<?php the_permalink(); ?>" rel="bookmark"><?php the_title(); ?></a>
		</h1>
		<?php
		}

		if ( comments_open() ) {
		?>
		<div class="comments-link">
			<?php comments_popup_link( '<span class="leave-reply">' . esc_html__( 'Leave a reply', 'simpods-mvc' ) . '</span>', esc_html__( '1 Reply', 'simpods-mvc' ), esc_html__( '% Replies', 'simpods-mvc' ) ); ?>
		</div>
		<?php } ?>
	</header>

	<!-- Body -->
	<?php

	if ( is_search() ) { // Only display Excerpts for Search ?>
	<div class="entry-summary">
		<?php the_excerpt(); ?>
	</div>
	<?php } else { ?>
	<div class="entry-content">
		<?php
		the_content( esc_html__( 'Continue reading <span class="meta-nav">&rarr;</span>', 'simpods-mvc' ) );
		wp_link_pages( array( 'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'simpods-mvc' ), 'after' => '</div>' ) );
		?>
	</div>
	<?php }

	?>

	<!-- Footer -->
	<footer class="entry-meta">
		<?php
		wp_link_pages( array( 'before' => '<div class="page-links">' . esc_html__( 'Pages:', 'simpods-mvc' ), 'after' => '</div>' ) );

		if ( is_singular() && get_the_author_meta( 'description' ) && is_multi_author() ) {
			// If a user has filled out their description and this is a multi-author blog, show a bio on their entries.
		?>
		<div class="author-info">
			<div class="author-avatar">
				<?php
				/* This filter is documented in author.php */
				$author_bio_avatar_size = apply_filters( 'simpods_author_bio_avatar_size', 68 );
				echo get_avatar( get_the_author_meta( 'user_email' ), $author_bio_avatar_size );
				?>
			</div>
			<div class="author-description">
				<h2>
				<?php
					/* translators: %s: author name */
					printf( esc_html__( 'About %s', 'simpods-mvc' ), get_the_author() );
				?>
				</h2>
				<p><?php the_author_meta( 'description' ); ?></p>
				<div class="author-link">
					<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" rel="author">
					<?php
						/* translators: %s: author name */
						printf( esc_html__( 'View all posts by %s <span class="meta-nav">&rarr;</span>', 'simpods-mvc' ), esc_html( get_the_author() ) );
					?>
					</a>
				</div>
			</div>
		</div>
		<?php } ?>
	</footer>
</article>
